@@ -27,7 +27,7 @@ object_name = os
 __package__ = os.path.basename(os.path.dirname(__file__))
 __author__ = "Dillon"
 __email__ = "aa269440877@outlook.com"
-__version__ = "1.0.3"
+__version__ = "1.0.4"
 __url__ = "https://gitee.com/ld269440877/tools/blob/master/my_modules/dir_objectName.py"
 __license__ = "MIT Licence"
 
@@ -429,16 +429,16 @@ But the value assigned to __name__ must be the name of the callable object.")
     return constants_list
 
 
-def adoc(object_name=object_name, print_classess=True, print_function_or_methods=True, print_constants=True):
+def adoc(object_name=object_name, pattern=r"^[^_]", print_classess=True, print_function_or_methods=True, print_constants=True):
     classify_dict = dict()
     if print_classess:
-        classify_dict.update({"classess": classes(object_name)})
+        classify_dict.update({"classess": classes(object_name, pattern=pattern)})
 
     if print_function_or_methods:
-        classify_dict.update({"function_or_methods": functions_or_methods(object_name)})
+        classify_dict.update({"function_or_methods": functions_or_methods(object_name, pattern=pattern)})
 
     if print_constants:
-        classify_dict.update({"constants": constants(object_name)})
+        classify_dict.update({"constants": constants(object_name, pattern=pattern)})
 
     print(f'\033[41m{getattr(object_name, "__name__", str(object_name))}\033[0m', [getattr(object_name, "__doc__", "__doc__ is not provided!")][0])
     for sub_object, attributes in classify_dict.items():
